package main

import (
	"context"
	"fmt"
	"log"

	"net/http"
	_ "net/http/pprof"

	"github.com/sirupsen/logrus"
	"gitlab.atsaero.ru/go-packages/atsami/ami"
)

const (
	user   = "ami_user"
	secret = "ami_user"
	//addr   = "192.168.68.178:5038"
	addr = "192.168.68.51:5038"
)

func main() {
	go func() {
		log.Println(http.ListenAndServe(":8080", nil))
	}()
	logger := logrus.New()
	logger.SetLevel(logrus.InfoLevel)
	logger.SetFormatter(&logrus.TextFormatter{ForceColors: true, DisableTimestamp: false, FullTimestamp: true})

	ctx, cancel := context.WithCancel(context.Background())
	defer cancel()

	client := ami.NewConnPool(ctx, user, secret, 3, 1, logger.WithField("module", "pool"), addr, addr)

	for i := 0; ; i++ {
		uuid := fmt.Sprintf("call_%d", i)

		// callback возвращает флаг завершения колбэка и ошибку. Если флаг завершения выставлен в true - колбэк удаляется из очереди выполнения
		callback := func(e ami.EventResponse) (bool, error) {
			if e.Event() == ami.EventUserEvent { // обработчик UserEvent
				logger.Infof("got UserEvent for %s: %s", e.Key(), e.Get("UserEvent"))
			}
			if e.Event() == ami.EventError { // обработчик Response
				logger.Errorf("got error: %v", e.Error())
			}
			return true, nil
		}

		// Originate
		// vars := `__AD_BNUM=880`
		// err := client.Originate(fmt.Sprintf("iteration-%d", i), "LOCAL/test@autodialer", "test", "autodialer-ivr-robott", vars, 70000, callback)
		// if err != nil {
		// 	logger.Errorf("originate sent %s failed: %v", uuid, err)
		// }

		// Ping
		err := client.Ping(fmt.Sprintf("iteration-%d", i), callback)
		if err != nil {
			logger.Errorf("ping sent %s failed: %v", uuid, err)
		}
		//time.Sleep(time.Millisecond * 10)
	}

	// воркеры обрабатывают очередь асинхронно. Управление состоянием осуществляется через вызовы отложенных функций, поэтому здесь необходима блокировка.
	select {}
}
